@@ -9,7 +9,7 @@ our $calendar;
 
 our $logger;
 
-our $VERSION = '1.08';
+our $VERSION = '2.02';
 
 # ------------------------------------------------
 
@@ -130,16 +130,6 @@ sub date_phrase
 
 # ------------------------------------------------
 
-sub day
-{
-	my($cache, $t1) = @_;
-
-	return $t1;
-
-} # End of day.
-
-# ------------------------------------------------
-
 sub estimated_date
 {
 	my($cache, $t1, $t2) = @_;
